@@ -1,16 +1,20 @@
 import csv
 from io import StringIO
+
+from django.utils.text import capfirst
+from django.utils.translation import gettext, gettext_lazy as _
 from django.views.generic.edit import CreateView, UpdateView
 from django.views.generic.detail import DetailView
 from django.views.generic.edit import FormMixin
 from django.utils.decorators import method_decorator
 from django.contrib.admin.views.decorators import staff_member_required
-from django.urls import reverse
+from django.urls import reverse, reverse_lazy
 from django.shortcuts import get_object_or_404, redirect
 from django.views.generic import View
 from django.http import JsonResponse, HttpResponse
 from django.contrib import messages
 
+from djf_surveys.app_settings import SURVEYS_ADMIN_BASE_PATH
 from djf_surveys.models import Survey, Question, UserAnswer
 from djf_surveys.mixin import ContextTitleMixin
 from djf_surveys.views import SurveyListView
@@ -26,14 +30,14 @@ class AdminCrateSurveyView(ContextTitleMixin, CreateView):
         'name', 'description', 'editable', 'deletable', 
         'duplicate_entry', 'private_response', 'can_anonymous_user'
     ]
-    title_page = "Add New Survey"
+    title_page = _("Add New Survey")
 
     def post(self, request, *args, **kwargs):
         form = self.get_form()
         if form.is_valid():
             survey = form.save()
             self.success_url = reverse("djf_surveys:admin_forms_survey", args=[survey.slug])
-            messages.success(self.request, f'Successfully {self.title_page}')
+            messages.success(self.request, gettext("%(page_action_name)s succeeded.") % dict(page_action_name=capfirst(self.title_page.lower())))
             return self.form_valid(form)
         else:
             return self.form_invalid(form)
@@ -47,7 +51,7 @@ class AdminEditSurveyView(ContextTitleMixin, UpdateView):
         'name', 'description', 'editable', 'deletable', 
         'duplicate_entry', 'private_response', 'can_anonymous_user'
     ]
-    title_page = "Edit Survey"
+    title_page = _("Edit Survey")
 
     def get_success_url(self):
         survey = self.get_object()
@@ -84,7 +88,7 @@ class AdminDeleteSurveyView(DetailView):
     def get(self, request, *args, **kwargs):
         survey = self.get_object()
         survey.delete()
-        messages.success(request, f'Successfully delete {survey.name}')
+        messages.success(request, gettext("Survey %(name)s succesfully deleted.") % dict(name=survey.name))
         return redirect("djf_surveys:admin_survey")
 
 
@@ -92,9 +96,9 @@ class AdminDeleteSurveyView(DetailView):
 class AdminCreateQuestionView(ContextTitleMixin, CreateView):
     model = Question
     template_name = 'djf_surveys/admins/question_form.html'
-    success_url = "/"
+    success_url = reverse_lazy("djf_surveys:")
     fields = ['label', 'key', 'type_field', 'choices', 'help_text', 'required']
-    title_page = 'Add Question'
+    title_page = _("Add Question")
     survey = None
 
     def dispatch(self, request, *args, **kwargs):
@@ -107,7 +111,7 @@ class AdminCreateQuestionView(ContextTitleMixin, CreateView):
             question = form.save(commit=False)
             question.survey = self.survey
             question.save()
-            messages.success(self.request, f'Successfully {self.title_page}')
+            messages.success(self.request, gettext("%(page_action_name)s succeeded.") % dict(page_action_name=capfirst(self.title_page.lower())))
             return self.form_valid(form)
         else:
             return self.form_invalid(form)
@@ -120,9 +124,9 @@ class AdminCreateQuestionView(ContextTitleMixin, CreateView):
 class AdminUpdateQuestionView(ContextTitleMixin, UpdateView):
     model = Question
     template_name = 'djf_surveys/admins/question_form.html'
-    success_url = "/"
+    success_url = SURVEYS_ADMIN_BASE_PATH
     fields = ['label', 'key', 'type_field', 'choices', 'help_text', 'required']
-    title_page = 'Add Question'
+    title_page = _("Add Question")
     survey = None
 
     def dispatch(self, request, *args, **kwargs):
@@ -147,7 +151,7 @@ class AdminDeleteQuestionView(DetailView):
     def get(self, request, *args, **kwargs):
         question = self.get_object()
         question.delete()
-        messages.success(request, f'Successfully delete {question.label}')
+        messages.success(request, gettext("Question %(name)s succesfully deleted.") % dict(name=question.label))
         return redirect("djf_surveys:admin_forms_survey", slug=self.survey.slug)
 
 
@@ -162,7 +166,7 @@ class AdminChangeOrderQuestionView(View):
                 question.save()
 
         data = {
-            'message': 'Success update ordering question'
+            'message': gettext("Update ordering of questions succeeded.")
         }
         return JsonResponse(data, status=200)
 
@@ -205,7 +209,7 @@ class DownloadResponseSurveyView(DetailView):
 class SummaryResponseSurveyView(ContextTitleMixin, DetailView):
     model = Survey
     template_name = "djf_surveys/admins/summary.html"
-    title_page = 'Summary'
+    title_page = _("Summary")
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
